==> systray-x_0.5.0.orig.tar.gz: systray-x-0.5.0/app/SysTray-X/languages/SysTray-X.de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.ui" line="14"/>
        <source>About SysTray-X</source>
        <translation>Über SysTray-X</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="26"/>
        <source>SysTray-X Companion App by Ximi1970</source>
        <translation>SysTray-X Companion App by Ximi1970</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="40"/>
        <source>Version:</source>
        <translation>Ausführung:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="47"/>
        <source>0.0.1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="54"/>
        <source>Build:</source>
        <translation>Build:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="61"/>
        <location filename="../aboutdialog.ui" line="75"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="68"/>
        <source>Hash:</source>
        <translation>Hash:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="82"/>
        <source>Branch:</source>
        <translation>Branch:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="89"/>
        <source>master</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>DebugWidget</name>
    <message>
        <location filename="../debugwidget.ui" line="14"/>
        <source>SysTray-X Debug</source>
        <translation>SysTray-X Debug</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="59"/>
        <source>Test 2</source>
        <translation>Test 2</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="69"/>
        <source>Unread mail:</source>
        <translation>Ungelesene Nachrichten:</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="76"/>
        <source>Test 1</source>
        <translation>Test 1</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="83"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="90"/>
        <source>Test 3</source>
        <translation>Test 3</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferences.ui" line="14"/>
        <source>SysTray-X Preferences</source>
        <translation>SysTray-X Einstellungen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="26"/>
        <source>Default icon</source>
        <translation>Standardsymbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="32"/>
        <source>Icon</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="40"/>
        <source>Default Thunderbird</source>
        <translation>Thunderbird Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="53"/>
        <source>Lookthrough icon</source>
        <translation>Unsichtbares Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="65"/>
        <location filename="../preferences.ui" line="188"/>
        <source>Custom icon</source>
        <translation>Benutzerdefiniert Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="82"/>
        <location filename="../preferences.ui" line="205"/>
        <source>Choose</source>
        <translation>Wählen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="99"/>
        <source>KDE integration (Hide)</source>
        <translation>KDE integration (Verbergen)</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="112"/>
        <source>Mail notification icon</source>
        <translation>E-Mail-Benachrichtigung Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="125"/>
        <source>Blank icon</source>
        <translation>Leeres Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="158"/>
        <source>New mail icon</source>
        <translation>Neue Nachricht Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="219"/>
        <source>No icon</source>
        <translation>Kein Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="266"/>
        <source>Windows</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="323"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="274"/>
        <source>Minimize</source>
        <translation>Minimieren</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="282"/>
        <source>Default minimize</source>
        <translation>Standard Minimieren</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="295"/>
        <source>Minimize to tray, method 1</source>
        <translation>In Systemleiste verbergen, Methode 1</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="308"/>
        <source>Minimize to tray, method 2</source>
        <translation>In Systemleiste verbergen, Methode 2</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="344"/>
        <source>Default close</source>
        <translation>Standard Schließen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="354"/>
        <source>Minimize main, close children</source>
        <translation>Hauptfenster minimieren, Kinderfenster schließen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="367"/>
        <source>Minimize all windows</source>
        <translation>Alle Fenster minimieren</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="387"/>
        <source>Start application minimized</source>
        <translation>Anwendung minimiert starten</translation>
    </message>
    <message>
        <source>Minimize on close</source>
        <translation type="vanished">Beim Fensterschließen, Minimieren</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="401"/>
        <source>Number properties</source>
        <translation>Nummereigenschaften</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="409"/>
        <source>Display unread message count</source>
        <translation>Anzahl neuer Nachrichten anzeigen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="421"/>
        <source>Number color</source>
        <translation>Nummerfarbe</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="442"/>
        <source>Number size</source>
        <translation>Nummergröße</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="464"/>
        <source>Count type</source>
        <translation>E-Mail-Benachrichtigungstyp</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="472"/>
        <source>Unread</source>
        <translation>Ungelesene Nachrichten</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="485"/>
        <source>New</source>
        <translation>Neue Nachrichten</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="522"/>
        <source>Display debug window</source>
        <translation>Debug-Fenster anzeigen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Speichern</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Annullieren</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="49"/>
        <location filename="../preferencesdialog.cpp" line="58"/>
        <source>Minimize to tray</source>
        <translation>Hauptfenster minimieren</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="370"/>
        <location filename="../preferencesdialog.cpp" line="394"/>
        <source>Open Image</source>
        <translation>Bild öffnen</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="370"/>
        <location filename="../preferencesdialog.cpp" line="394"/>
        <source>Image Files (*.png *.jpg *.bmp)</source>
        <translation>Bilddateien (*.png *.jpg *.bmp)</translation>
    </message>
</context>
<context>
    <name>SysTrayX</name>
    <message>
        <location filename="../systrayx.cpp" line="192"/>
        <source>&amp;Show/Hide</source>
        <translation>&amp;Anzeigen/Verbergen</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="196"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="200"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="204"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="602"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
</TS>

==> systray-x_0.6.1.orig.tar.gz: systray-x-0.6.1/app/SysTray-X/languages/SysTray-X.de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.ui" line="14"/>
        <source>About SysTray-X</source>
        <translation>Über SysTray-X</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="26"/>
        <source>SysTray-X Companion App by Ximi1970</source>
        <translation>SysTray-X Companion App by Ximi1970</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="40"/>
        <source>Version:</source>
        <translation>Ausführung:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="47"/>
        <source>0.0.1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="54"/>
        <source>Build:</source>
        <translation>Build:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="61"/>
        <location filename="../aboutdialog.ui" line="75"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="68"/>
        <source>Hash:</source>
        <translation>Hash:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="82"/>
        <source>Branch:</source>
        <translation>Branch:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.ui" line="89"/>
        <source>master</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>DebugWidget</name>
    <message>
        <location filename="../debugwidget.ui" line="14"/>
        <source>SysTray-X Debug</source>
        <translation>SysTray-X Debug</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="59"/>
        <source>Test 2</source>
        <translation>Test 2</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="69"/>
        <source>Unread mail:</source>
        <translation>Ungelesene Nachrichten:</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="76"/>
        <source>Test 1</source>
        <translation>Test 1</translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="83"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../debugwidget.ui" line="90"/>
        <source>Test 3</source>
        <translation>Test 3</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferences.ui" line="14"/>
        <source>SysTray-X Preferences</source>
        <translation>SysTray-X Einstellungen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="26"/>
        <source>Default icon</source>
        <translation>Standardsymbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="32"/>
        <source>Icon</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="40"/>
        <source>Default Thunderbird</source>
        <translation>Thunderbird Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="53"/>
        <source>Lookthrough icon</source>
        <translation>Unsichtbares Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="65"/>
        <location filename="../preferences.ui" line="201"/>
        <source>Custom icon</source>
        <translation>Benutzerdefiniert Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="82"/>
        <location filename="../preferences.ui" line="218"/>
        <source>Choose</source>
        <translation>Wählen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="99"/>
        <source>KDE integration (Hide)</source>
        <translation>KDE integration (Verbergen)</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="112"/>
        <source>Mail notification icon</source>
        <translation>E-Mail-Benachrichtigung Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="138"/>
        <source>Blank icon</source>
        <translation>Leeres Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="171"/>
        <source>New mail icon</source>
        <translation>Neue Nachricht Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="232"/>
        <source>No icon</source>
        <translation>Kein Symbol</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="279"/>
        <source>Windows</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="336"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="287"/>
        <source>Minimize</source>
        <translation>Minimieren</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="295"/>
        <source>Default minimize</source>
        <translation>Standard Minimieren</translation>
    </message>
    <message>
        <source>Minimize to tray, method 1</source>
        <translation type="vanished">In Systemleiste verbergen, Methode 1</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="321"/>
        <source>Minimize to tray, method 2</source>
        <translation>In Systemleiste verbergen, Methode 2</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="344"/>
        <source>Default close</source>
        <translation>Standard Schließen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="354"/>
        <source>Minimize main, close children</source>
        <translation>Hauptfenster minimieren, Kinderfenster schließen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="367"/>
        <source>Minimize all windows</source>
        <translation>Alle Fenster minimieren</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="387"/>
        <source>Start application minimized</source>
        <translation>Anwendung minimiert starten</translation>
    </message>
    <message>
        <source>Minimize on close</source>
        <translation type="vanished">Beim Fensterschließen, Minimieren</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="401"/>
        <source>Number properties</source>
        <translation>Nummereigenschaften</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="409"/>
        <source>Display unread message count</source>
        <translation>Anzahl neuer Nachrichten anzeigen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="421"/>
        <source>Number color</source>
        <translation>Nummerfarbe</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="442"/>
        <source>Number size</source>
        <translation>Nummergröße</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="464"/>
        <source>Count type</source>
        <translation>E-Mail-Benachrichtigungstyp</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="472"/>
        <source>Unread</source>
        <translation>Ungelesene Nachrichten</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="485"/>
        <source>New</source>
        <translation>Neue Nachrichten</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="522"/>
        <source>Display debug window</source>
        <translation>Debug-Fenster anzeigen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="542"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="549"/>
        <source>Cancel</source>
        <translation>Annullieren</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="308"/>
        <location filename="../preferencesdialog.cpp" line="52"/>
        <location filename="../preferencesdialog.cpp" line="63"/>
        <source>Minimize to tray</source>
        <translation>Hauptfenster minimieren</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="391"/>
        <location filename="../preferencesdialog.cpp" line="415"/>
        <source>Open Image</source>
        <translation>Bild öffnen</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="391"/>
        <location filename="../preferencesdialog.cpp" line="415"/>
        <source>Image Files (*.png *.jpg *.bmp)</source>
        <translation>Bilddateien (*.png *.jpg *.bmp)</translation>
    </message>
</context>
<context>
    <name>SysTrayX</name>
    <message>
        <location filename="../systrayx.cpp" line="194"/>
        <source>&amp;Show/Hide</source>
        <translation>&amp;Anzeigen/Verbergen</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="198"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="202"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="206"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../systrayx.cpp" line="604"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
</context>
</TS>
